@@ -90,7 +90,7 @@ class QuickDB:
         else:
             return pd.Series(result)
 
-    def getTradables(self, start, end=None, tipsonly=False, firstonly=False, lastonly=False):
+    def getTradables(self, start, end=None, index=""):
         """
         date에 거래정지, 정리매매 상태가 아닌 종목을 list로 반환.
         Args:
@@ -103,15 +103,20 @@ class QuickDB:
             end = start
         trdstp = self.getTS(88, start, end).replace({1:0, 0:1})
         liqsell = self.getTS(92, start, end).replace({1:0, 0:1})
+        liqsell.loc[:'20090320'] = 1 
+        # 090320 이전까지는 데이터 없음.
+        # 따라서 1로 처리해서 trdstp가 1인 경우 1x1 = 1이 되도록, trdstp가 0인 경우 1x0=0이 되도록 처리
         tradable = trdstp * liqsell
-        if firstonly:
-            return tradable.iloc[0].where(lmabda x : x == 1).dropna(axis=1).columns.to_list()
-        elif lastonly:
-            return tradable.iloc[-1].where(lmabda x : x == 1).dropna(axis=1).columns.to_list()
-        elif tipsonly:
+        if index.upper() == "FIRST":
+            return tradable.iloc[0:1].where(lambda x : x == 1).dropna(axis=1).columns.to_list()
+        elif index.upper() == "LAST":
+            return tradable.iloc[-1:].where(lambda x : x == 1).dropna(axis=1).columns.to_list()
+        elif index.upper() == "TIPS":
             idx = [tradable.index[0], tradable.index[-1]] 
             return tradable.loc[idx].where(lambda x : x == 1).dropna(axis=1).columns.to_list()
         else:
+            if len(tradable) == 0:
+                return []
             return tradable
         # tradable = (trdstp * liqsell).where(lambda x : x == 1).dropna(axis=1)
         # if tradable.shape[0]:
